//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ListBox_Item_Spacing
{
    public partial class Form1 : Form
    {
        #region Initialization
        public Form1()
        {
            InitializeComponent();

            this.listBox1.NormalItemStyle.BorderColor = Color.LightGray;
            this.listBox1.ScrollStep = LidorSystems.IntegralUI.Lists.ScrollStep.Pixel;

            CreateLabelContent();

            InitList();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   This sample shows how to increase space between items and how to use margin and padding to change the distance between item and control border and also between item border and its content.</p><br></br>";
            content += "<p>   To change the distance between items we are using the <b>ItemSpacing</b> property. Any value between 0 and 255 is allowed.</p><br></br>";
            content += "<p>   To change the distance between item border and control border we are using the <b>Margin</b> property which allows to set a different value for each item side.</p><br></br>";
            content += "<p>   Similarly to change the distance between item border and its content elements we are using the <b>Padding</b> property which allows to set a different value for each item side.</p><br></br>";
            content += "<p>   From control panel you can change the values for these properties and see their effect. If you want to set spacing for individual item, first select it, uncheck the Style From Parent and than change its margin or padding values. To switch back to settings for all items, click on Reset button</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr><td width=\"100%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/listbox/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
                System.Diagnostics.Process.Start((e.Object as LinkLabel).Links[0].LinkData.ToString());
        }

        private void InitList()
        {
            this.listBox1.SuspendUpdate();

            LidorSystems.IntegralUI.Lists.ListBoxItem item = null;
            for (int i = 1; i <= 100; i++)
            {
                item = new LidorSystems.IntegralUI.Lists.ListBoxItem("Item " + i.ToString());

                this.listBox1.Items.Add(item);
            }

            this.listBox1.ResumeUpdate();
        }
        #endregion

        #region Item Spacing
        private void numSpacing_ValueChanged(object sender, EventArgs e)
        {
            this.listBox1.ItemSpacing = (int)numSpacing.Value;
        }

        private void btnSeparator_Click(object sender, EventArgs e)
        {
            ColorDialog cDlg = new ColorDialog();
            if (cDlg.ShowDialog() == DialogResult.OK)
                this.listBox1.ColorStyle.ItemSeparatorColor = cDlg.Color;
        }
        #endregion

        #region Margin and Padding
        private void listBox1_AfterSelect(object sender, LidorSystems.IntegralUI.ObjectEventArgs e)
        {
            if (e.Object is LidorSystems.IntegralUI.Lists.ListBoxItem)
            {
                LidorSystems.IntegralUI.Lists.ListBoxItem item = (LidorSystems.IntegralUI.Lists.ListBoxItem)e.Object;

                selItemLabel.Text = item.Text;
                styleFromParent.Enabled = true;
                styleFromParent.Checked = item.StyleFromParent;

                rbMargin.Checked = true;

                if (item.StyleFromParent)
                {
                    numLeft.Value = this.listBox1.ItemFormatStyle.Margin.Left;
                    numTop.Value = this.listBox1.ItemFormatStyle.Margin.Top;
                    numRight.Value = this.listBox1.ItemFormatStyle.Margin.Right;
                    numBottom.Value = this.listBox1.ItemFormatStyle.Margin.Bottom;
                }
                else
                {
                    numLeft.Value = item.FormatStyle.Margin.Left;
                    numTop.Value = item.FormatStyle.Margin.Top;
                    numRight.Value = item.FormatStyle.Margin.Right;
                    numBottom.Value = item.FormatStyle.Margin.Bottom;
                }
            }
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            selItemLabel.Text = String.Empty;
            this.listBox1.SelectedItem = null;
            styleFromParent.Enabled = false;

            UpdateMarginPaddingValues();
        }

        private void styleFromParent_CheckedChanged(object sender, EventArgs e)
        {
            if (this.listBox1.SelectedItem != null)
            {
                this.listBox1.SelectedItem.StyleFromParent = styleFromParent.Checked;
                this.listBox1.SelectedItem.NormalStyle.BorderColor = Color.LightGray;

                UpdateMarginPaddingValues();
            }
        }

        private void btnApply_Click(object sender, EventArgs e)
        {
            // Apply changes to Margin and Padding for a specific item (selected one in this case)
            if (!styleFromParent.Checked && this.listBox1.SelectedItem != null)
            {
                if (rbMargin.Checked)
                    this.listBox1.SelectedItem.FormatStyle.Margin = new Padding((int)numLeft.Value, (int)numTop.Value, (int)numRight.Value, (int)numBottom.Value);
                else
                    this.listBox1.SelectedItem.FormatStyle.Padding = new Padding((int)numLeft.Value, (int)numTop.Value, (int)numRight.Value, (int)numBottom.Value);

                this.listBox1.UpdateCurrentView();
            }
            // Apply changes to Margin and Padding for all items
            else
            {
                if (rbMargin.Checked)
                    this.listBox1.ItemFormatStyle.Margin = new Padding((int)numLeft.Value, (int)numTop.Value, (int)numRight.Value, (int)numBottom.Value);
                else
                    this.listBox1.ItemFormatStyle.Padding = new Padding((int)numLeft.Value, (int)numTop.Value, (int)numRight.Value, (int)numBottom.Value);
            }
        }

        private void MarginPadding_CheckedChanged(object sender, EventArgs e)
        {
            UpdateMarginPaddingValues();
        }

        private void UpdateMarginPaddingValues()
        {
            LidorSystems.IntegralUI.Lists.ListBoxItem item = this.listBox1.SelectedItem;

            if (rbMargin.Checked)
            {
                if (item != null && !item.StyleFromParent)
                {
                    numLeft.Value = item.FormatStyle.Margin.Left;
                    numTop.Value = item.FormatStyle.Margin.Top;
                    numRight.Value = item.FormatStyle.Margin.Right;
                    numBottom.Value = item.FormatStyle.Margin.Bottom;
                }
                else
                {
                    numLeft.Value = this.listBox1.ItemFormatStyle.Margin.Left;
                    numTop.Value = this.listBox1.ItemFormatStyle.Margin.Top;
                    numRight.Value = this.listBox1.ItemFormatStyle.Margin.Right;
                    numBottom.Value = this.listBox1.ItemFormatStyle.Margin.Bottom;
                }
            }
            else
            {
                if (item != null && !item.StyleFromParent)
                {
                    numLeft.Value = item.FormatStyle.Padding.Left;
                    numTop.Value = item.FormatStyle.Padding.Top;
                    numRight.Value = item.FormatStyle.Padding.Right;
                    numBottom.Value = item.FormatStyle.Padding.Bottom;
                }
                else
                {
                    numLeft.Value = this.listBox1.ItemFormatStyle.Padding.Left;
                    numTop.Value = this.listBox1.ItemFormatStyle.Padding.Top;
                    numRight.Value = this.listBox1.ItemFormatStyle.Padding.Right;
                    numBottom.Value = this.listBox1.ItemFormatStyle.Padding.Bottom;
                }
            }
        }
        #endregion
    }
}